==> beagle-0.2.4.tar.bz2: beagle-0.2.4/Util/IoPriority.cs <==
//
// IoPriority.cs
//
// Copyright (C) 2005 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Runtime.InteropServices;

namespace Beagle.Util {
	
	public class IoPriority {

		private IoPriority () {} // Static class

		[DllImport ("libbeagleglue")]
		static extern int set_io_priority_idle ();

		static public void SetIdle ()
		{
			// Continue with a warning if we can't set the 
			// IO-priority to idle, not a big deal.
			if (set_io_priority_idle () == -1)
				Logger.Log.Warn ("Unable to set IO-priority for process to idle");
		}
	}
}

==> beagle-0.2.10.tar.bz2: beagle-0.2.10/Util/IoPriority.cs <==
//
// IoPriority.cs
//
// Copyright (C) 2005 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Runtime.InteropServices;

namespace Beagle.Util {
	
	public class IoPriority {

		private IoPriority () {} // Static class

		[DllImport ("libbeagleglue")]
		static extern int set_io_priority_idle ();

		[DllImport ("libbeagleglue")]
		static extern int set_io_priority_best_effort (int ioprio);

		static public bool SetIdle ()
		{
			// Continue with a warning if we can't set the 
			// IO-priority to idle, not a big deal.
			if (set_io_priority_idle () == -1) {
				Logger.Log.Warn ("Unable to set IO priority for process to idle");
				return false;
			}

			Logger.Log.Debug ("IO priority for process set to idle");
			return true;
		}

		static public bool SetIoPriority (int ioprio)
		{
			if (set_io_priority_best_effort (ioprio) == -1) {
				Logger.Log.Warn ("Unable to set best effort IO priority for process to {0}", ioprio);
				return false;
			}

			Logger.Log.Debug ("IO priority for process set to best effort {0}", ioprio);
			return true;
		}
	}
}
